@@ -36,24 +36,24 @@ func TestAudit(t *testing.T) {
 	t.Run("expect audit complaints on very weak passwords", func(t *testing.T) {
 		sec := secrets.NewAKV()
 		sec.SetPassword("123")
-		assert.NoError(t, act.Store.Set(ctx, "bar", sec))
-		assert.NoError(t, act.Store.Set(ctx, "baz", sec))
+		require.NoError(t, act.Store.Set(ctx, "bar", sec))
+		require.NoError(t, act.Store.Set(ctx, "baz", sec))
 
-		assert.Error(t, act.Audit(gptest.CliCtx(ctx, t)))
+		require.Error(t, act.Audit(gptest.CliCtx(ctx, t)))
 		buf.Reset()
 	})
 
 	t.Run("test with filter and very passwords", func(t *testing.T) {
 		c := gptest.CliCtx(ctx, t, "foo")
-		assert.Error(t, act.Audit(c))
+		require.Error(t, act.Audit(c))
 		buf.Reset()
 	})
 
 	t.Run("test empty store", func(t *testing.T) {
 		for _, v := range []string{"foo", "bar", "baz"} {
-			assert.NoError(t, act.Store.Delete(ctx, v))
+			require.NoError(t, act.Store.Delete(ctx, v))
 		}
-		assert.NoError(t, act.Audit(gptest.CliCtx(ctx, t)))
+		require.NoError(t, act.Audit(gptest.CliCtx(ctx, t)))
 		assert.Contains(t, "No secrets found", buf.String())
 		buf.Reset()
 	})
