@@ -34,10 +34,10 @@ func TestBinary(t *testing.T) {
 	require.NotNil(t, act)
 	ctx = act.cfg.WithConfig(ctx)
 
-	assert.Error(t, act.Cat(gptest.CliCtx(ctx, t)))
-	assert.Error(t, act.BinaryCopy(gptest.CliCtx(ctx, t)))
-	assert.Error(t, act.BinaryMove(gptest.CliCtx(ctx, t)))
-	assert.Error(t, act.Sum(gptest.CliCtx(ctx, t)))
+	require.Error(t, act.Cat(gptest.CliCtx(ctx, t)))
+	require.Error(t, act.BinaryCopy(gptest.CliCtx(ctx, t)))
+	require.Error(t, act.BinaryMove(gptest.CliCtx(ctx, t)))
+	require.Error(t, act.Sum(gptest.CliCtx(ctx, t)))
 }
 
 func TestBinaryCat(t *testing.T) {
@@ -66,11 +66,11 @@ func TestBinaryCat(t *testing.T) {
 	writeBinfile(t, infile, tSize)
 
 	t.Run("populate store", func(t *testing.T) {
-		assert.NoError(t, act.binaryCopy(ctx, gptest.CliCtx(ctx, t), infile, "bar", true))
+		require.NoError(t, act.binaryCopy(ctx, gptest.CliCtx(ctx, t), infile, "bar", true))
 	})
 
 	t.Run("binary cat bar", func(t *testing.T) {
-		assert.NoError(t, act.Cat(gptest.CliCtx(ctx, t, "bar")))
+		require.NoError(t, act.Cat(gptest.CliCtx(ctx, t, "bar")))
 	})
 
 	stdinfile := filepath.Join(u.Dir, "stdin")
@@ -78,14 +78,14 @@ func TestBinaryCat(t *testing.T) {
 		writeBinfile(t, stdinfile, tSize)
 
 		fd, err := os.Open(stdinfile)
-		assert.NoError(t, err)
+		require.NoError(t, err)
 		binstdin = fd
 		defer func() {
 			binstdin = os.Stdin
 			_ = fd.Close()
 		}()
 
-		assert.NoError(t, act.Cat(gptest.CliCtx(ctx, t, "baz")))
+		require.NoError(t, act.Cat(gptest.CliCtx(ctx, t, "baz")))
 	})
 
 	t.Run("compare output", func(t *testing.T) {
@@ -123,7 +123,7 @@ func TestBinaryCatSizes(t *testing.T) {
 		writeBinfile(t, stdinfile, tSize)
 
 		fd, err := os.Open(stdinfile)
-		assert.NoError(t, err)
+		require.NoError(t, err)
 
 		catFn := func() {
 			binstdin = fd
@@ -132,7 +132,7 @@ func TestBinaryCatSizes(t *testing.T) {
 				_ = fd.Close()
 			}()
 
-			assert.NoError(t, act.Cat(gptest.CliCtx(ctx, t, "baz")))
+			require.NoError(t, act.Cat(gptest.CliCtx(ctx, t, "baz")))
 		}
 		catFn()
 
@@ -173,8 +173,8 @@ func TestBinaryCopy(t *testing.T) {
 		defer buf.Reset()
 
 		infile := filepath.Join(u.Dir, "input.txt")
-		assert.NoError(t, os.WriteFile(infile, []byte("0xDEADBEEF\n"), 0o644))
-		assert.NoError(t, act.binaryCopy(ctx, gptest.CliCtx(ctx, t), infile, "txt", true))
+		require.NoError(t, os.WriteFile(infile, []byte("0xDEADBEEF\n"), 0o644))
+		require.NoError(t, act.binaryCopy(ctx, gptest.CliCtx(ctx, t), infile, "txt", true))
 	})
 
 	infile := filepath.Join(u.Dir, "input.raw")
@@ -183,33 +183,33 @@ func TestBinaryCopy(t *testing.T) {
 		defer buf.Reset()
 
 		writeBinfile(t, infile, 1024)
-		assert.NoError(t, act.binaryCopy(ctx, gptest.CliCtx(ctx, t), infile, "bar", true))
+		require.NoError(t, act.binaryCopy(ctx, gptest.CliCtx(ctx, t), infile, "bar", true))
 	})
 
 	t.Run("binary copy bar tempdir/bar", func(t *testing.T) {
 		defer buf.Reset()
-		assert.NoError(t, act.BinaryCopy(gptest.CliCtx(ctx, t, "bar", outfile)))
+		require.NoError(t, act.BinaryCopy(gptest.CliCtx(ctx, t, "bar", outfile)))
 	})
 
 	t.Run("binary copy tempdir/bar tempdir/bar", func(t *testing.T) {
 		defer buf.Reset()
 
-		assert.Error(t, act.BinaryCopy(gptest.CliCtx(ctx, t, outfile, outfile)))
+		require.Error(t, act.BinaryCopy(gptest.CliCtx(ctx, t, outfile, outfile)))
 	})
 
 	t.Run("binary copy bar bar", func(t *testing.T) {
 		defer buf.Reset()
-		assert.Error(t, act.BinaryCopy(gptest.CliCtx(ctx, t, "bar", "bar")))
+		require.Error(t, act.BinaryCopy(gptest.CliCtx(ctx, t, "bar", "bar")))
 	})
 
 	t.Run("binary move tempdir/bar bar2", func(t *testing.T) {
 		defer buf.Reset()
-		assert.NoError(t, act.BinaryMove(gptest.CliCtx(ctx, t, outfile, "bar2")))
+		require.NoError(t, act.BinaryMove(gptest.CliCtx(ctx, t, outfile, "bar2")))
 	})
 
 	t.Run("binary move bar2 tempdir/bar", func(t *testing.T) {
 		defer buf.Reset()
-		assert.NoError(t, act.BinaryMove(gptest.CliCtx(ctx, t, "bar2", outfile)))
+		require.NoError(t, act.BinaryMove(gptest.CliCtx(ctx, t, "bar2", outfile)))
 	})
 }
 
@@ -235,11 +235,11 @@ func TestBinarySum(t *testing.T) {
 
 	t.Run("populate store", func(t *testing.T) {
 		writeBinfile(t, infile, 1024)
-		assert.NoError(t, act.binaryCopy(ctx, gptest.CliCtx(ctx, t), infile, "bar", true))
+		require.NoError(t, act.binaryCopy(ctx, gptest.CliCtx(ctx, t), infile, "bar", true))
 	})
 
 	t.Run("binary sum bar", func(t *testing.T) {
-		assert.NoError(t, act.Sum(gptest.CliCtx(ctx, t, "bar")))
+		require.NoError(t, act.Sum(gptest.CliCtx(ctx, t, "bar")))
 		buf.Reset()
 	})
 }
@@ -257,10 +257,10 @@ func TestBinaryGet(t *testing.T) {
 	ctx = act.cfg.WithConfig(ctx)
 
 	data := []byte("1\n2\n3\n")
-	assert.NoError(t, act.insertStdin(ctx, "x", data, false))
+	require.NoError(t, act.insertStdin(ctx, "x", data, false))
 
 	out, err := act.binaryGet(ctx, "x")
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, data, out)
 }
 
@@ -272,7 +272,7 @@ func writeBinfile(t *testing.T, fn string, size int) {
 
 	buf := make([]byte, size)
 	n, err := lr.Read(buf)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, size, n)
-	assert.NoError(t, os.WriteFile(fn, buf, 0o644))
+	require.NoError(t, os.WriteFile(fn, buf, 0o644))
 }
