@@ -38,7 +38,7 @@ func TestGenerate(t *testing.T) {
 	require.NotNil(t, act)
 	ctx = act.cfg.WithConfig(ctx)
 
-	require.NoError(t, act.cfg.Set("", "core.autoclip", "false"))
+	require.NoError(t, act.cfg.Set("", "generate.autoclip", "false"))
 
 	buf := &bytes.Buffer{}
 	out.Stdout = buf
@@ -51,7 +51,7 @@ func TestGenerate(t *testing.T) {
 
 	// generate
 	t.Run("generate", func(t *testing.T) {
-		assert.Error(t, act.Generate(gptest.CliCtx(ctx, t)))
+		require.Error(t, act.Generate(gptest.CliCtx(ctx, t)))
 		buf.Reset()
 	})
 
@@ -61,7 +61,7 @@ func TestGenerate(t *testing.T) {
 			t.Skip("skipping test in short mode.")
 		}
 
-		assert.NoError(t, act.Generate(gptest.CliCtx(ctx, t, "foobar")))
+		require.NoError(t, act.Generate(gptest.CliCtx(ctx, t, "foobar")))
 		buf.Reset()
 	})
 
@@ -72,7 +72,7 @@ func TestGenerate(t *testing.T) {
 			t.Skip("skipping test in short mode.")
 		}
 
-		assert.NoError(t, act.Generate(gptest.CliCtx(ctx, t, "foobar")))
+		require.NoError(t, act.Generate(gptest.CliCtx(ctx, t, "foobar")))
 		buf.Reset()
 	})
 
@@ -82,7 +82,7 @@ func TestGenerate(t *testing.T) {
 			t.Skip("skipping test in short mode.")
 		}
 
-		assert.NoError(t, act.Generate(gptest.CliCtxWithFlags(ctx, t, map[string]string{"edit": "true", "editor": "/bin/cat"}, "foobar")))
+		require.NoError(t, act.Generate(gptest.CliCtxWithFlags(ctx, t, map[string]string{"edit": "true", "editor": "/bin/cat"}, "foobar")))
 		buf.Reset()
 	})
 
@@ -92,7 +92,7 @@ func TestGenerate(t *testing.T) {
 			t.Skip("skipping test in short mode.")
 		}
 
-		assert.NoError(t, act.Generate(gptest.CliCtxWithFlags(ctx, t, map[string]string{"force": "true"}, "foobar")))
+		require.NoError(t, act.Generate(gptest.CliCtxWithFlags(ctx, t, map[string]string{"force": "true"}, "foobar")))
 		buf.Reset()
 	})
 
@@ -102,7 +102,7 @@ func TestGenerate(t *testing.T) {
 			t.Skip("skipping test in short mode.")
 		}
 
-		assert.NoError(t, act.Generate(gptest.CliCtxWithFlags(ctx, t, map[string]string{"force": "true"}, "foobar", "32")))
+		require.NoError(t, act.Generate(gptest.CliCtxWithFlags(ctx, t, map[string]string{"force": "true"}, "foobar", "32")))
 		buf.Reset()
 	})
 
@@ -112,7 +112,7 @@ func TestGenerate(t *testing.T) {
 			t.Skip("skipping test in short mode.")
 		}
 
-		assert.NoError(t, act.Generate(gptest.CliCtxWithFlags(ctx, t, map[string]string{"force": "true", "print": "true", "symbols": "true"}, "foobar", "32")))
+		require.NoError(t, act.Generate(gptest.CliCtxWithFlags(ctx, t, map[string]string{"force": "true", "print": "true", "symbols": "true"}, "foobar", "32")))
 		passIsAlphaNum(t, buf.String(), false)
 		buf.Reset()
 	})
@@ -123,57 +123,57 @@ func TestGenerate(t *testing.T) {
 			t.Skip("skipping test in short mode.")
 		}
 
-		assert.NoError(t, act.Generate(gptest.CliCtxWithFlags(ctx, t, map[string]string{"force": "true", "print": "true", "symbols": "false"}, "foobar", "32")))
+		require.NoError(t, act.Generate(gptest.CliCtxWithFlags(ctx, t, map[string]string{"force": "true", "print": "true", "symbols": "false"}, "foobar", "32")))
 		passIsAlphaNum(t, buf.String(), true)
 		buf.Reset()
 	})
 
 	// generate --force --xkcd foobar 32
 	t.Run("generate --force --xkcd foobar 32", func(t *testing.T) {
-		assert.NoError(t, act.Generate(gptest.CliCtxWithFlags(ctx, t, map[string]string{"force": "true", "xkcd": "true", "lang": "en"}, "foobar", "32")))
+		require.NoError(t, act.Generate(gptest.CliCtxWithFlags(ctx, t, map[string]string{"force": "true", "xkcd": "true", "lang": "en"}, "foobar", "32")))
 		buf.Reset()
 	})
 
 	// generate --force --xkcd foobar baz 32
 	t.Run("generate --force --xkcd foobar baz 32", func(t *testing.T) {
-		assert.NoError(t, act.Generate(gptest.CliCtxWithFlags(ctx, t, map[string]string{"force": "true", "xkcd": "true", "lang": "en"}, "foobar", "baz", "32")))
+		require.NoError(t, act.Generate(gptest.CliCtxWithFlags(ctx, t, map[string]string{"force": "true", "xkcd": "true", "lang": "en"}, "foobar", "baz", "32")))
 		buf.Reset()
 	})
 
 	// generate --force --xkcd foobar baz
 	t.Run("generate --force --xkcd foobar baz", func(t *testing.T) {
-		assert.NoError(t, act.Generate(gptest.CliCtxWithFlags(ctx, t, map[string]string{"force": "true", "xkcd": "true", "lang": "en"}, "foobar", "baz")))
+		require.NoError(t, act.Generate(gptest.CliCtxWithFlags(ctx, t, map[string]string{"force": "true", "xkcd": "true", "lang": "en"}, "foobar", "baz")))
 		buf.Reset()
 	})
 
 	// generate --force --xkcd --print foobar baz
 	t.Run("generate --force --xkcd --print foobar baz", func(t *testing.T) {
-		assert.NoError(t, act.Generate(gptest.CliCtxWithFlags(ctx, t, map[string]string{"force": "true", "xkcd": "true", "print": "true", "lang": "en"}, "foobar", "baz")))
+		require.NoError(t, act.Generate(gptest.CliCtxWithFlags(ctx, t, map[string]string{"force": "true", "xkcd": "true", "print": "true", "lang": "en"}, "foobar", "baz")))
 		buf.Reset()
 	})
 
 	// generate --force foobar 24 w/ autoclip and output redirection
 	t.Run("generate --force foobar 24", func(t *testing.T) {
-		ov := act.cfg.Get("core.autoclip")
+		ov := act.cfg.Get("generate.autoclip")
 		defer func() {
-			require.NoError(t, act.cfg.Set("", "core.autoclip", ov))
+			require.NoError(t, act.cfg.Set("", "generate.autoclip", ov))
 		}()
-		require.NoError(t, act.cfg.Set("", "core.autoclip", "true"))
+		require.NoError(t, act.cfg.Set("", "generate.autoclip", "true"))
 		ctx := ctxutil.WithTerminal(ctx, false)
-		assert.NoError(t, act.Generate(gptest.CliCtxWithFlags(ctx, t, map[string]string{"force": "true"}, "foobar", "24")))
+		require.NoError(t, act.Generate(gptest.CliCtxWithFlags(ctx, t, map[string]string{"force": "true"}, "foobar", "24")))
 		assert.Contains(t, buf.String(), "Not printing secrets by default")
 		buf.Reset()
 	})
 
 	// generate --force foobar 24 w/ autoclip and no output redirection
 	t.Run("generate --force foobar 24", func(t *testing.T) {
-		ov := act.cfg.Get("core.autoclip")
+		ov := act.cfg.Get("generate.autoclip")
 		defer func() {
-			require.NoError(t, act.cfg.Set("", "core.autoclip", ov))
+			require.NoError(t, act.cfg.Set("", "generate.autoclip", ov))
 		}()
-		require.NoError(t, act.cfg.Set("", "core.autoclip", "true"))
+		require.NoError(t, act.cfg.Set("", "generate.autoclip", "true"))
 		ctx := ctxutil.WithTerminal(ctx, true)
-		assert.NoError(t, act.Generate(gptest.CliCtxWithFlags(ctx, t, map[string]string{"force": "true"}, "foobar", "24")))
+		require.NoError(t, act.Generate(gptest.CliCtxWithFlags(ctx, t, map[string]string{"force": "true"}, "foobar", "24")))
 		assert.Contains(t, buf.String(), "Copied to clipboard")
 		buf.Reset()
 	})
@@ -182,7 +182,7 @@ func TestGenerate(t *testing.T) {
 	t.Run("generate --force foobar", func(t *testing.T) {
 		t.Setenv("GOPASS_PW_DEFAULT_LENGTH", "42")
 
-		assert.NoError(t, act.Generate(gptest.CliCtxWithFlags(ctx, t, map[string]string{"force": "true", "print": "true", "symbols": "false"}, "foobar")))
+		require.NoError(t, act.Generate(gptest.CliCtxWithFlags(ctx, t, map[string]string{"force": "true", "print": "true", "symbols": "false"}, "foobar")))
 		lines := strings.Split(strings.TrimSpace(buf.String()), "\n")
 		assert.Len(t, lines[3], 42)
 		buf.Reset()
@@ -196,7 +196,7 @@ func TestGenerate(t *testing.T) {
 			t.Skip("skipping test in short mode.")
 		}
 
-		assert.NoError(t, act.Generate(gptest.CliCtxWithFlags(ctx, t, map[string]string{"force": "true", "print": "true", "symbols": "false"}, "foobar")))
+		require.NoError(t, act.Generate(gptest.CliCtxWithFlags(ctx, t, map[string]string{"force": "true", "print": "true", "symbols": "false"}, "foobar")))
 		lines := strings.Split(strings.TrimSpace(buf.String()), "\n")
 		assert.Len(t, lines[3], 24) // 24 = default value used as fallback
 		buf.Reset()
@@ -249,7 +249,7 @@ func TestKeyAndLength(t *testing.T) {
 		t.Run(fmt.Sprintf("%v", tc.in), func(t *testing.T) {
 			app := cli.NewApp()
 			fs := flag.NewFlagSet("default", flag.ContinueOnError)
-			assert.NoError(t, fs.Parse(append([]string{"foobar"}, tc.in...)))
+			require.NoError(t, fs.Parse(append([]string{"foobar"}, tc.in...)))
 			c := cli.NewContext(app, fs, nil)
 			args, _ := parseArgs(c)
 			k, l := keyAndLength(args)
@@ -356,7 +356,7 @@ func TestDefaultLengthFromEnv(t *testing.T) {
 	t.Run("use default value if no environment variable is set", func(t *testing.T) {
 		actual, isCustom := config.DefaultPasswordLengthFromEnv(ctx)
 		expected := config.DefaultPasswordLength
-		assert.Equal(t, actual, expected)
+		assert.Equal(t, expected, actual)
 		assert.False(t, isCustom)
 	})
 
@@ -375,7 +375,7 @@ func TestDefaultLengthFromEnv(t *testing.T) {
 			tc := tc
 			t.Setenv(pwLengthEnvName, tc.in)
 			actual, isCustom := config.DefaultPasswordLengthFromEnv(ctx)
-			assert.Equal(t, actual, tc.expected)
+			assert.Equal(t, tc.expected, actual)
 			assert.Equal(t, isCustom, tc.custom)
 		}
 	})
